@@ -48,6 +48,7 @@ from .pattern import (
     EFFECT_CUSTOM_CODE,
     EFFECT_ID_NAME,
     EFFECT_LIST,
+    EFFECT_LIST_DIMMABLE,
     ORIGINAL_ADDRESSABLE_EFFECT_ID_NAME,
     ORIGINAL_ADDRESSABLE_EFFECT_NAME_ID,
     PresetPattern,
@@ -317,6 +318,12 @@ class LEDENETDevice:
         assert self._protocol is not None
         return self._protocol.dimmable_effects
 
+    @property
+    def requires_turn_on(self) -> bool:
+        """Return true of the device requires a power on command before setting levels/effects."""
+        assert self._protocol is not None
+        return self._protocol.requires_turn_on
+
     @property
     def is_on(self) -> bool:
         assert self.raw_state is not None
@@ -342,7 +349,7 @@ class LEDENETDevice:
         elif protocol in NEW_EFFECTS_PROTOCOLS:
             effects = ADDRESSABLE_EFFECT_ID_NAME.values()
         elif COLOR_MODES_RGB.intersection(self.color_modes):
-            effects = EFFECT_LIST
+            effects = EFFECT_LIST_DIMMABLE if self.dimmable_effects else EFFECT_LIST
         return [*effects, EFFECT_RANDOM]
 
     @property
@@ -890,14 +897,14 @@ class LEDENETDevice:
         protocol = self.protocol
         if protocol in OLD_EFFECTS_PROTOCOLS:
             if pattern not in ORIGINAL_ADDRESSABLE_EFFECT_ID_NAME:
-                raise ValueError("Pattern must be between 1 and 300")
+                raise ValueError("Pattern must be between 1 and 302")
         elif protocol in NEW_EFFECTS_PROTOCOLS:
             if pattern not in ADDRESSABLE_EFFECT_ID_NAME:
                 raise ValueError("Pattern must be between 1 and 100")
         else:
             PresetPattern.valtostr(pattern)
             if not PresetPattern.valid(pattern):
-                raise ValueError("Pattern must be between 0x25 and 0x38")
+                raise ValueError("Pattern must be between 0x25 and 0x39")
         if not (1 <= brightness <= 100):
             raise ValueError("Brightness must be between 1 and 100")
         self._last_effect_brightness = brightness
