@@ -141,6 +141,11 @@ class ProtocolBase:
         self._counter = 0
         super().__init__()
 
+    @property
+    def requires_turn_on(self) -> bool:
+        """If True the device must be turned on before setting level/patterns/modes."""
+        return True
+
     def _increment_counter(self) -> int:
         """Increment the counter byte."""
         self._counter += 1
@@ -534,6 +539,11 @@ class ProtocolLEDENET8ByteDimmableEffects(ProtocolLEDENET8Byte):
         """Protocol supports dimmable effects."""
         return True
 
+    @property
+    def requires_turn_on(self) -> bool:
+        """If True the device must be turned on before setting level/patterns/modes."""
+        return False
+
     @property
     def name(self) -> str:
         """The name of the protocol."""
@@ -608,6 +618,11 @@ class ProtocolLEDENET9ByteDimmableEffects(ProtocolLEDENET9Byte):
         """The name of the protocol."""
         return PROTOCOL_LEDENET_9BYTE_DIMMABLE_EFFECTS
 
+    @property
+    def requires_turn_on(self) -> bool:
+        """If True the device must be turned on before setting level/patterns/modes."""
+        return False
+
     def construct_preset_pattern(
         self, pattern: int, speed: int, brightness: int
     ) -> bytearray:
@@ -627,6 +642,11 @@ class ProtocolLEDENETAddressableA1(ProtocolLEDENET9Byte):
         """Protocol supports dimmable effects."""
         return False
 
+    @property
+    def requires_turn_on(self) -> bool:
+        """If True the device must be turned on before setting level/patterns/modes."""
+        return False
+
     def construct_preset_pattern(
         self, pattern: int, speed: int, brightness: int
     ) -> bytearray:
@@ -648,6 +668,11 @@ class ProtocolLEDENETAddressableA2(ProtocolLEDENET9Byte):
         """Protocol supports dimmable effects."""
         return True
 
+    @property
+    def requires_turn_on(self) -> bool:
+        """If True the device must be turned on before setting level/patterns/modes."""
+        return False
+
     def construct_preset_pattern(
         self, pattern: int, speed: int, brightness: int
     ) -> bytearray:
@@ -760,6 +785,11 @@ class ProtocolLEDENETAddressableA3(ProtocolLEDENET9Byte):
         """Protocol supports dimmable effects."""
         return True
 
+    @property
+    def requires_turn_on(self) -> bool:
+        """If True the device must be turned on before setting level/patterns/modes."""
+        return False
+
     def construct_preset_pattern(
         self, pattern: int, speed: int, brightness: int
     ) -> bytearray:
@@ -921,6 +951,11 @@ class ProtocolLEDENETCCT(ProtocolLEDENET9Byte):
         """Protocol supports dimmable effects."""
         return False
 
+    @property
+    def requires_turn_on(self) -> bool:
+        """If True the device must be turned on before setting level/patterns/modes."""
+        return False
+
     def construct_levels_change(
         self,
         persist: int,
